*****************************************
Converting to and from other data formats
*****************************************
.. currentmodule:: networkx

To NetworkX Graph
-----------------
.. automodule:: networkx.convert

.. autosummary::
   :toctree: generated/

   to_networkx_graph

Relabeling
----------
.. autosummary::
   :toctree: generated/

   convert_node_labels_to_integers
   relabel_nodes


Dictionaries
------------
.. autosummary::
   :toctree: generated/

   to_dict_of_dicts
   from_dict_of_dicts

Lists
-----
.. autosummary::
   :toctree: generated/

   to_dict_of_lists
   from_dict_of_lists
   to_edgelist
   from_edgelist

Numpy
-----
.. autosummary::
   :toctree: generated/

   to_numpy_matrix
   from_numpy_matrix

Scipy
-----
.. autosummary::
   :toctree: generated/

   to_scipy_sparse_matrix
   from_scipy_sparse_matrix
